// Copyright (c) 2003 Charles Samuels <charles@kde.org>
// See the file COPYING for redistribution terms.

#include "kdatacollection.h"

#include <kconfig.h>
#include <kglobal.h>
#include <kstandarddirs.h>

#include <qfile.h>
#include <qfileinfo.h>


KDataCollection::KDataCollection(
		KConfig *config, const QString &group, const QString &entry,
		const char *datadir, const QString &dir
	)
{
	init(config, group, entry, datadir, dir);
}

KDataCollection::KDataCollection(
		KConfig *config, const QString &group, const QString &entry,
		const QString &dir
	)
{
	init(config, group, entry, "appdata", dir);
}

KDataCollection::KDataCollection(
		KConfig *config, const QString &group, const QString &dir
	)
{
	init(config, group, dir, "appdata", dir);
}

KDataCollection::KDataCollection(KConfig *config, const QString &dir)
{
	init(config, "KDataCollection", dir, "appdata", dir);
}

KDataCollection::KDataCollection(const QString &dir)
{
	init(KGlobal::config(), "KDataCollection", dir, "appdata", dir);
}

void KDataCollection::init(
		KConfig *config, const QString &group, const QString &entry,
		const char *datadir, const QString &dir
	)
{
	mConfig = config;
	mGroup = group;
	mEntry = entry;
	mDir = dir;
	mDatadir = datadir;
}

QStringList KDataCollection::names() const
{
	KConfigGroup g(mConfig, mGroup);

	// these are the entries I have
	QStringList n = g.readListEntry(mEntry);
	QStringList fs = KGlobal::dirs()->findAllResources(mDatadir, mDir+"/*");
	QStringList total;

	for (QStringList::Iterator i(fs.begin()); i != fs.end(); ++i)
	{
		QFileInfo fi(*i);
		QString name = fi.fileName();
		if (!n.contains(name))
		{
			total.append(name);
		}
	}

	return total;
}

void KDataCollection::remove(const QString &name)
{
	KConfigGroup g(mConfig, mGroup);
	QString location = file(name);
	if (location.isEmpty()) return;
	if (location == saveFile(name))
	{
		QFile(location).remove();
		// is there a system one too?
		location = file(name, false);
		if (location.isEmpty()) return;
	}

	QStringList n = g.readListEntry(mEntry);
	if (n.contains(name)) return;
	n.append(name);
	g.writeEntry(mEntry, n);
}

QString KDataCollection::file(const QString &name, bool create)
{
	QString path = ::locate(mDatadir, mDir+"/"+name);

	if (path.isEmpty() && create)
	{
		path = KGlobal::dirs()->saveLocation(mDatadir, mDir+"/"+name);
	}
	return path;
}

QString KDataCollection::saveFile(const QString &name, bool create)
{
	if (KGlobal::dirs()->isRestrictedResource(mDatadir, mDir+"/"+name))
		return KGlobal::dirs()->saveLocation(mDatadir, mDir+"/"+name, create);
	return QString::null;
}


